@@ -6,7 +6,7 @@ package Dist::Iller::Config::Author::CSSON;
 
 # ABSTRACT: Dist::Iller config
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0310';
+our $VERSION = '0.0311';
 
 use Moose;
 use namespace::autoclean;
@@ -158,8 +158,8 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0310"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller-Config-Author-CSSON/0.0310" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0310"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0310" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0311"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Iller-Config-Author-CSSON/0.0311" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0311"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0311" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" />
 </p>
 
@@ -167,7 +167,7 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =head1 VERSION
 
-Version 0.0310, released 2016-06-30.
+Version 0.0311, released 2016-08-11.
 
 
 
